Examples 
====================

pyscreenshot/examples/show.py:

.. literalinclude:: ../pyscreenshot/examples/show.py

to start:: 

    python -m pyscreenshot.examples.show


pyscreenshot/examples/showall.py:

.. literalinclude:: ../pyscreenshot/examples/showall.py

to start:: 

    python -m pyscreenshot.examples.showall

    